# 10.6.2012, End of Line: UNIX

# The R-code to redo the analysis done in the paper. 

rm(list=ls());

# The functions used to perform the tests. 
# Note that a spatial median is computed using 
# the implementation of package 'pcaPP'. 
source("test-biom.R");


# # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # The Bumpuses’s sparrows data  # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # 
DATA <- read.table("sparrows.csv", sep = ";", dec = ".", header=TRUE);

# A function used to standardized each column of the data
stand <- function(x){
  vysl <- (x - mean(x))/sd(x);
  return(vysl);
}

# Standardized data
DATAs <- apply(DATA[,1:5], 2, stand);
ident.sparrows <- DATA$status;

# # F_{d}-test + centring with a spatial median
# Fd.test(DATAs, ident = ident.sparrows, n.perm=999, Fdlog = FALSE, input="data", centring="median");
# The result of this test is not presented in the paper. 

# F_{d}-test + centring with a centroid
fit.sparrows <- Fd.test(DATAs, ident = ident.sparrows, n.perm=999, Fdlog = FALSE, input="data", centring="centroid");
# The same results as in the paper can be obtained by
# set.seed(2012); Fd.test(DATAs, ident = ident.sparrows, n.perm=99999, Fdlog = FALSE, input="data", centring="centroid");
# Similarly for the other tests.

# F_{d}^{log}-test + centring with a spatial median
# Fd.test(DATAs, ident = ident.sparrows, n.perm=999, Fdlog = TRUE, input="data", centring="median");
# The result of this test is not presented in the paper. 

# F_{d}^{log}-test + centring with a centroid
Fd.test(DATAs, ident = ident.sparrows, n.perm=999, Fdlog = TRUE, input="data", centring="centroid");

# # 
# F_{And} + centring with a spatial median
FAnd.test(DATAs, ident = ident.sparrows, n.perm=999, input="data", centring="median");

# F_{And} + centring with a centroid
FAnd.test(DATAs, ident = ident.sparrows, n.perm=999, input="data", centring="centroid");


# # Figure 1
# Mean distances from the i-the observations
Di.spar <- fit.sparrows$Di;

# postscript(file="sparrows.eps", width=7, height=5);
nn <- as.numeric(table(fit.sparrows$ident));
xx <- c(rep(c(1,2), nn));
plot(xx, Di.spar, xaxt="n", xlab="", ylab="Mean Euclidean distance", main = "Bumpus' sparrows", xlim=c(0.5,2.5), ylim=c(1.9, 5.15));
axis(side=1, at=c(2,1), labels=fit.sparrows$groups, cex.axis=1.1);
# mean within distances
dk <- fit.sparrows$mu;
points(c(1,2)+0.125, dk[c(2,1)], pch=c(4,4), lwd=2);
# Estimate of the standard deviation of dk
est.sd <- sqrt(fit.sparrows$sigma/nn);
# Confidence interval
ci1 <- dk[2] + qt(0.975, df=nn[2])*est.sd[2]*c(-1,1);
ci2 <- dk[1] + qt(0.975, df=nn[1])*est.sd[1]*c(-1,1);
# ci1
lines(c(1,1)+0.125,ci1, lty="dotted");
points(c(1,1)+0.125, ci1, pch=c(3,3));
# ci2
lines(c(2,2)+0.125,ci2, lty="dotted");
points(c(2,2)+0.125, ci2, pch=c(3,3));

legend(0.55, 5.15, pch=c(4,3), legend=c(expression(paste("Mean within-group distance - ", " ", bar(d)[k])), expression(paste("Limits of 95% confidence interval"))), pt.lwd=c(2,1), cex=1.1);
# dev.off();

# # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # The Tikus Island corals data  # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # 

load("tikus.RData");
# Alternatively one can make use of the package "mvabund"
# library(mvabund);
# data(tikus);

library(vegan);
# If the package "vegan" is not available, one cannot use 
# the function "vegdist" and the Bray-Curtis distance matrix 
# has to be calculated in a different way.
mat.corals <- as.matrix(vegdist(sqrt(tikus$abund), method="bray"));
ident.corals <- as.factor(tikus$x$time);

# F_{d}-test + centring with a spatial median
# Fd.test(mat.corals, ident = ident.corals, n.perm=999, Fdlog = FALSE, input="distances", centring="median");
# The result of this test is not presented in the paper. 

# F_{d}-test + centring with a centroid
fit.corals <- Fd.test(mat.corals, ident = ident.corals, n.perm=999, Fdlog = FALSE, input="distances", centring="centroid");

# F_{d}^{log}-test + centring with a spatial median
# Fd.test(mat.corals, ident = ident.corals, n.perm=999, Fdlog = TRUE, input="distances", centring="median");
# The result of this test is not presented in the paper. 

# F_{d}^{log}-test + centring with a centroid
Fd.test(mat.corals, ident = ident.corals, n.perm=999, Fdlog = TRUE, input="distances", centring="centroid");

# # 
# F_{And} + centring with a spatial median
FAnd.test(mat.corals, ident = ident.corals, n.perm=999, input="distances", centring="median");

# F_{And} + centring with a centroid
FAnd.test(mat.corals, ident = ident.corals, n.perm=999, input="distances", centring="centroid");


# # Figure 2
# postscript(file="corals.eps", width=10, height=5);
Di.cor <- fit.corals$Di;
nn <- table(fit.corals$ident);

xx <- c(rep(c(1,2,3,4,5,6), nn));
plot(xx, Di.cor, xaxt="n", xlab="", ylab="Mean Bray-Curtis dissimilarity", xlim=c(0.5,6.5), ylim=c(0.4,1.05), main="Tikus Islands corals");
axis(side=1, at=c(1,2,3,4,5,6), labels=(c(1981,1983,1984,1985,1987,1988)));
# est.mu <- tapply(Di.cor, xx, mean);
dk <- fit.corals$mu;
posun <- 0.25
points(c(1:6)+posun, dk, pch=c(4,4), lwd=2);
est.sd <- sqrt(fit.corals$sigma/nn);
# est.sd <- sqrt(4*tapply(Di.cor, ident.corals, var)*(nn-1)^2/(nn-2)^2/nn);

CI <- matrix(NA, 6, 2);
for(i in 1:6){
	CI[i,] <- dk[i] + qt(0.975, df=nn[i])*est.sd[i]*c(-1,1);
	
	lines(c(i,i)+posun,CI[i,], lty="dotted");
	points(c(i,i)+posun, CI[i,], pch=c(3,3));
}
legend(3.5, 1.05, pch=c(4,3), legend=c(expression(paste("Mean within-group distance - ", " ", bar(d)[k])), expression(paste("Limits of 95% confidence  interval"))), pt.lwd=c(2,1), cex=1);
# dev.off();
